pub struct RBEvent {
pub data_type: DataType,
pub status: EventStatus,
pub header: RBEventHeader,
pub adc: Vec<Vec<u16>>,
pub hits: Vec<TofHit>,
pub creation_time: Option<Instant>,
}Expand description
Event data for each individual ReadoutBoard (RB)
Fields
data_type: DataTypestatus: EventStatusheader: RBEventHeaderadc: Vec<Vec<u16>>hits: Vec<TofHit>creation_time: Option<Instant>Implementations
Sourceimpl RBEvent
impl RBEvent
pub fn new() -> Self
pub fn trace_check(&self) -> bool
pub fn has_any_mangling_flag(&self) -> bool
Sourcepub fn self_check(&self) -> Result<(), AnalysisError>
pub fn self_check(&self) -> Result<(), AnalysisError>
Check if we have all the channel data even as indicated by the header
Sourcepub fn get_rbwaveforms(&self) -> Vec<RBWaveform>
pub fn get_rbwaveforms(&self) -> Vec<RBWaveform>
Deconstruct the RBEvent to form RBWaveforms
Sourcepub fn extract_datatype(
stream: &Vec<u8>,
) -> Result<DataType, SerializationError>
pub fn extract_datatype( stream: &Vec<u8>, ) -> Result<DataType, SerializationError>
Get the datatype from a bytestream when we know that it is an RBEvent
The data type is encoded in byte 3
Sourcepub fn get_channel_packet_len(
stream: &Vec<u8>,
pos: usize,
) -> Result<(usize, Vec<u8>), SerializationError>
pub fn get_channel_packet_len( stream: &Vec<u8>, pos: usize, ) -> Result<(usize, Vec<u8>), SerializationError>
decode the len field in the in memroy represention of RBEventMemoryView
Sourcepub fn extract_eventid(stream: &Vec<u8>) -> Result<u32, SerializationError>
pub fn extract_eventid(stream: &Vec<u8>) -> Result<u32, SerializationError>
Get the event id from a RBEvent represented by bytestream without decoding the whole event
This should be faster than decoding the whole event.
pub fn get_ndatachan(&self) -> usize
pub fn get_channel_by_id(&self, ch: usize) -> Result<&Vec<u16>, UserError>
pub fn get_channel_by_label(&self, ch: u8) -> Result<&Vec<u16>, UserError>
Sourcepub fn from_bytestream_nowaveforms(
stream: &Vec<u8>,
pos: &mut usize,
) -> Result<Self, SerializationError>
pub fn from_bytestream_nowaveforms( stream: &Vec<u8>, pos: &mut usize, ) -> Result<Self, SerializationError>
Similar to the “official” from_bytestream, this will get the event from a bytestream, omitting the waveforms. This will allow for a faster readout in case waveforms are not needed.